import three;
import math;
texpreamble("\usepackage{bm}");

size(300,0);


currentprojection=perspective(6,-1,5); 
//currentprojection=perspective(6,8,2); 

// random phi for incoming ray, just so axes don't align 
// and mistakes in the remaining code come to light.
real phi_i = 45;

// Incident ray parameters 
real graze = 40;

// Scatter parameters
real theta = 20;
real phi = 20;

pen p1=rgb(0.7,0,0) + dashed;

// Surface Normal
triple n = (0,0,-1);

// Incident Ray (this is a direction vector). 
triple r_i = -dir(-(90-graze), phi_i);

// base vectors for planes
triple u = unit(cross(r_i, n ));
triple v = cross(u, n );

// note that v is in the plane of the reflecting surface (it is
// perpendicular to n) and in the plane of specular reflection
// (it is perpendicular to u, which is perpendicular to r_i)

// incident angle
real theta_i = dot(r_i,v);

// Reflected ray
triple r_r = r_i - 2 * dot(r_i, n) * n;

real pscale = 1.2;

face[] faces;

path3 plane_surface = scale3(pscale) * (v+u -- u-v -- -u-v -- v-u -- cycle3);
path3 plane_spec = scale3(pscale) * ( v -- v-n -- -v-n -- -v -- cycle3);
path3 plane_i = scale3(pscale) * ( -r_i-u -- -r_i+u -- u -- -u -- cycle3);
path3 plane_r = scale3(pscale) * ( r_r-u -- r_r+u -- u -- -u -- cycle3);

pen border = gray(0.5);
filldraw( faces.push( plane_surface ), plane_surface, gray(0.9), border );
filldraw( faces.push( plane_spec ), plane_spec, gray(0.8), border );
filldraw( faces.push( plane_i ), plane_i, gray(0.85), border );
filldraw( faces.push( plane_r ), plane_r, gray(0.85), border );

add( faces );

draw(Label("$\hat{n}$", 0.8), O--n,p1,Arrow, align = 2E);
draw(rotate(40)*Label("$\hat{u} = r_i\times\hat{n}$"), O--u,p1,Arrow, align=1.5N+W);
draw(rotate(-25)*Label("$\hat{v} = \hat{u}\times\hat{n}$"), align=W+S, O--v,p1,Arrow);

draw(Label("$r_i$"), -r_i--O,Arrow);
draw(Label("$r_r$", 0.8), O--r_r,Arrow, align=N);


//--------------------------------------
// construct in-plane scatter vector. the scattered angle is theta,
// where theta is relative to r_r, and is positive in the forward
// scattering direction.   r_st dot r_r = cos(theta).

// first, construct basis vector in specular plane (bsp) perp. to r_r
// such that rotation of r_r into bsp about u is in the forward
// scattering direction
triple bsp = cross(u,r_r);

// here's the in-plane scattered vector
triple r_st = r_r * cos(radians(theta)) + bsp * sin(radians(theta));
draw(Label("$\delta r_\theta$", 1), r_r--r_st,Arrow);

//--------------------------------------
// construct out-of-plane scattered vector. phi is relative to r_r, i.e.
// r_sp dot r_r = cos(phi).

triple r_sp = r_r * cos(radians(phi)) + u * sin(radians(phi));
draw(Label("$\delta r_\phi$", 1),  r_r--r_sp,Arrow);

triple r_s = r_r + (r_sp - r_r) + (r_st - r_r);
draw(Label("$r_s$", 1), O--r_s ,Arrow);

write( "r_s: ", r_s );
write( "length(r_s): ", length(r_s) );

draw( r_sp -- r_s, linetype("4 4") );
draw( r_st -- r_s, linetype("4 4") );

pen parc = dashed + gray(0.5);
draw( arc(O, v, -v, normal = u ), parc );
draw( arc(O, u, -u, normal = bsp, direction=CCW), parc );

// draw outlines of planes and axes so that they continue across the hidden
// portions. this relies upon the solid borders drawn above in
// the filldraw commands.
pen outline_border = dotted + border;
draw( scale3(pscale) * (v -- -v), outline_border );
draw( scale3(pscale) * (u -- -u), outline_border );
draw( plane_i, outline_border );
draw( plane_r, outline_border );
draw( plane_spec, outline_border );


// draw the intrinsic axes, if needed.
//pen p=rgb(0,0.7,0) + dashed;
//draw(Label("$x$",1),O--pscale*X,p,Arrow);
//draw(Label("$y$",1),O--pscale*Y,p,Arrow);
//draw(Label("$z$",1),O--pscale*Z,p,Arrow);


real sin_at = sin( radians( graze - theta ) );
real cos_at = cos( radians( graze - theta ) );
real sin_a  = sin( radians( graze ) );
real cos_a  = cos( radians( graze ) );
real cos_p  = cos( radians( phi ) );
real sin_p  = sin( radians( phi ) );

real xi = cos_at / cos_a;
real f1 = - sin_at + xi * sin_a * cos_p;
triple q = cross( r_r, n );
triple s = f1 * n + xi * ( cos_p * r_r + sin_p * q);

draw ( Label("S", 1), O--s, Arrow );
write( "S: ", s );


triple Sp = n   * ( -sin_at + sin_a / cos_a * cos_at ) +
            r_r * ( cos_at / cos_a + cos_p -1 ) +
	    unit(q) * sin_p ;

draw ( Label("Sp", 1), O--Sp, Arrow );
write( "Sp: ", Sp );
