// --8<--8<--8<--8<--
//
// Copyright (C) 2006 Smithsonian Astrophysical Observatory
//
// This file is part of scatter
//
// scatter is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// scatter is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the
//       Free Software Foundation, Inc.
//       51 Franklin Street, Fifth Floor
//       Boston, MA  02110-1301, USA
//
// -->8-->8-->8-->8--

#include <cstdlib>
#include <iostream>
#include <libgen.h>

#include <cxcparamx/simple.h>
#include <suplib/debug.h>
#include <tracefctxx/TraceFct.h>

#include "config.h"
#include "help.hpp"
#include "usage.hpp"
#include "process.h"

using namespace std;

int main( int argc, char* argv[] ) {
  TraceFct tf( argv[0], 0, 1 );

  try {
      cxcparamx::simple pf( argc, argv );

    if ( pf.getb( "help" ) ) {
      help( );
      return EXIT_SUCCESS;
    }

    if ( pf.getb( "usage" ) ) {
      usage( );
      return EXIT_SUCCESS;
    }

    if ( pf.getb( "version" ) ) {
      cout << basename( argv[0] ) << " version " << VERSION << endl;
      return EXIT_SUCCESS;
    }

    tf.open( pf.getstr( "logfile" ) );

    debug_init( pf.getstr( "debug" ).c_str( ) );

    process( pf );

  } catch ( Exception& E ) {
    tf.exit( EXIT_FAILURE, E );

  } catch ( exception& e ) {
    tf.exit( EXIT_FAILURE, e.what( ) );

  } catch ( ... ) {
    tf.exit( EXIT_FAILURE, const_cast<char*>("Unrecognized exception caught") );

  }

  return EXIT_SUCCESS;

}
