. tests/common.sh

#------------------------------------------------------

test_initialize
test_set_hook result test_result_hook_save_output_on_failure

#------------------------------------------------------
# check that backscattered rays are treated correctly

test_begin_subtests

# 90 deg - 50 arcminutes + 1 arcsecond.  Should be 1 arcmin backscattered.
theta=321001
phi=3000

test_name='surface test 2'

$TEST_SCATTER                                   \
       --seed1 $SEED1                           \
       --seed2 $SEED2                           \
       --block $BLOCK                           \
       --nrays=1                                \
       --no-in_plane                            \
       --no-out_of_plane                        \
       --alpha  50                              \
       --energy 1.0                             \
       --theta $theta                           \
       --phi   $phi                             \
       --tag=$(testpfx)                         \
       --srcdir=$scatter_dir                    \
       --zpos=0                                 \
       --mirror_db='${INPUTDIR}/mirror.rdb'     \
       --scatter_db='${INPUTDIR}/sawtooth.rdb'

test_is $? 0 "$test_name: generate"

test_file_grep_is 'backscattered:  1' $(testpfx).scatter.log \
		  "$test_name: log message"

naxis2=$(fitskey $(testpfx).scatter.calc.fits NAXIS2)
test_num_is "$naxis2" 0 "$test_name: backscattered"

test_end_subtests

#------------------------------------------------------
# check that backscattered rays are treated correctly

test_begin_subtests

# 90 deg - 50 arcminutes - 1 arcsecond.  Should be darn close to being
# back scattered.
theta=320999
phi=3000

test_name='surface test 3'

$TEST_SCATTER                                   \
       --seed1 $SEED1                           \
       --seed2 $SEED2                           \
       --block $BLOCK                           \
       --nrays=1                                \
       --no-in_plane                            \
       --no-out_of_plane                        \
       --alpha  50                              \
       --energy 1.0                             \
       --theta $theta                           \
       --phi   $phi                             \
       --tag=$(testpfx)                         \
       --srcdir=$scatter_dir                    \
       --zpos=0                                 \
       --mirror_db='${INPUTDIR}/mirror.rdb'     \
       --scatter_db='${INPUTDIR}/sawtooth.rdb'

test_is $? 0 "$test_name: generate"

test_file_grep_is 'backscattered:  0' $(testpfx).scatter.log \
		  "$test_name: log message"

naxis2=$(fitskey $(testpfx).scatter.calc.fits NAXIS2)
test_num_is "$naxis2" 1 "$test_name: almost backscattered"

test_end_subtests

test_summary
test_exit
